Pyzmo
=====

Pyzmo is a small hotkey library for Python **2.7+** based on
python-evdev_. It can call arbitrary Python functions in response to
key presses, key chords (simultaneously pressed keys) and key
sequences (keys pressed in succession).

Documentation:
    http://pyzmo.readthedocs.org/en/latest/

Development:
    https://github.com/gvalkov/pyzmo

Package:
    http://pypi.python.org/pypi/pyzmo

.. _python-evdev:      https://github.com/gvalkov/python-evdev.git
